AiChatRepo class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ List<
AiChatItem> -
no setter
-
stream
→ Stream<
List< AiChatItem> > -
A broadcast that never emits errors
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sync(
List< AiChatItem> inserts, List<String> deletes) → Future<void> - This call should be atomic to ensure data integrity
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited