sync abstract method
This call should be atomic to ensure data integrity
Implementation
Future<void> sync(List<AiChatItem> inserts, List<String> deletes);
This call should be atomic to ensure data integrity
Future<void> sync(List<AiChatItem> inserts, List<String> deletes);