AiChatState class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
AiChatState({required String chatId, required List<
AiChatItem> items}) -
constfactory
Properties
- chatId → String
-
no setterinherited
-
conversationItems
→ List<
AiConversationItem> -
Available on AiChatState, provided by the AiChatStateX extension
no setter -
copyWith
→ $AiChatStateCopyWith<
AiChatState> -
Create a copy of AiChatState
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
AiChatItem> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_AiChatState value)) → TResult -
Available on AiChatState, provided by the AiChatStatePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_AiChatState value)?) → TResult? -
Available on AiChatState, provided by the AiChatStatePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_AiChatState value)?, {required TResult orElse()}) → TResult -
Available on AiChatState, provided by the AiChatStatePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String chatId, List< AiChatItem> items)?, {required TResult orElse()}) → TResult -
Available on AiChatState, provided by the AiChatStatePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String chatId, List< AiChatItem> items)) → TResult -
Available on AiChatState, provided by the AiChatStatePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String chatId, List< AiChatItem> items)?) → TResult? -
Available on AiChatState, provided by the AiChatStatePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited