InMemoryAiChatRepo class

Inheritance
Implemented types

Constructors

InMemoryAiChatRepo()

Properties

hashCode int
The hash code for this object.
no setterinherited
mounted bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedStream Stream<List<AiChatItem>>
no setterinherited
state List<AiChatItem>
getter/setter pairinherited
stream Stream<List<AiChatItem>>
no setterinherited

Methods

dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sync(List<AiChatItem> inserts, List<String> deletes) Future<void>
This call should be atomic to ensure data integrity
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited